bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma
============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianToGaussianGamma

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianToGaussianGamma.__init__
      ~GaussianToGaussianGamma.add_plate_axis
      ~GaussianToGaussianGamma.broadcasting_multiplier
      ~GaussianToGaussianGamma.delete
      ~GaussianToGaussianGamma.get_mask
      ~GaussianToGaussianGamma.get_moments
      ~GaussianToGaussianGamma.get_shape
      ~GaussianToGaussianGamma.has_plotter
      ~GaussianToGaussianGamma.lower_bound_contribution
      ~GaussianToGaussianGamma.move_plates
      ~GaussianToGaussianGamma.plot
      ~GaussianToGaussianGamma.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianToGaussianGamma.plates
      ~GaussianToGaussianGamma.plates_multiplier
   
   